==> bw-xml-synchws-4.0.7-sources.jar: org/oasis_open/docs/ws_calendar/ns/soap/GetPropertiesResponseType.java <==

package org.oasis_open.docs.ws_calendar.ns.soap;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *          Respond to the getProperties request. The response contains the href 
 *          of the targeted resource and a set of properties for that resource.
 *       
 * 
 * <p>Java class for GetPropertiesResponseType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GetPropertiesResponseType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://docs.oasis-open.org/ws-calendar/ns/soap}BaseResponseType">
 *       &lt;sequence>
 *         &lt;element name="href" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;choice maxOccurs="unbounded" minOccurs="0">
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}childCollection"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}creationDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}displayName"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}lastModifiedDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxAttendeesPerInstance"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxInstances"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxResourceSize"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}minDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}principalHome"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceDescription"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceOwner"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceType"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceTimezoneId"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}supportedCalendarComponentSet"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}supportedFeatures"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}timezoneServer"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GetPropertiesResponseType", propOrder = {
    "href",
    "childCollectionOrCreationDateTimeOrDisplayName"
})
public class GetPropertiesResponseType
    extends BaseResponseType
{

    @XmlElement(required = true)
    protected String href;
    @XmlElements({
        @XmlElement(name = "resourceType", type = ResourceTypeType.class),
        @XmlElement(name = "maxDateTime", type = MaxDateTimeType.class),
        @XmlElement(name = "resourceOwner", type = ResourceOwnerType.class),
        @XmlElement(name = "maxResourceSize", type = MaxResourceSizeType.class),
        @XmlElement(name = "supportedCalendarComponentSet", type = SupportedCalendarComponentSetType.class),
        @XmlElement(name = "lastModifiedDateTime", type = LastModifiedDateTimeType.class),
        @XmlElement(name = "resourceDescription", type = ResourceDescriptionType.class),
        @XmlElement(name = "resourceTimezoneId", type = ResourceTimezoneIdType.class),
        @XmlElement(name = "supportedFeatures", type = SupportedFeaturesType.class),
        @XmlElement(name = "minDateTime", type = MinDateTimeType.class),
        @XmlElement(name = "maxInstances", type = MaxInstancesType.class),
        @XmlElement(name = "principalHome", type = PrincipalHomeType.class),
        @XmlElement(name = "timezoneServer", type = TimezoneServerType.class),
        @XmlElement(name = "maxAttendeesPerInstance", type = MaxAttendeesPerInstanceType.class),
        @XmlElement(name = "childCollection", type = ChildCollectionType.class),
        @XmlElement(name = "creationDateTime", type = CreationDateTimeType.class),
        @XmlElement(name = "displayName", type = DisplayNameType.class)
    })
    protected List<GetPropertiesBasePropertyType> childCollectionOrCreationDateTimeOrDisplayName;

    /**
     * Gets the value of the href property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHref() {
        return href;
    }

    /**
     * Sets the value of the href property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHref(String value) {
        this.href = value;
    }

    /**
     * Gets the value of the childCollectionOrCreationDateTimeOrDisplayName property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the childCollectionOrCreationDateTimeOrDisplayName property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildCollectionOrCreationDateTimeOrDisplayName().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ResourceTypeType }
     * {@link MaxDateTimeType }
     * {@link ResourceOwnerType }
     * {@link MaxResourceSizeType }
     * {@link SupportedCalendarComponentSetType }
     * {@link LastModifiedDateTimeType }
     * {@link ResourceDescriptionType }
     * {@link ResourceTimezoneIdType }
     * {@link SupportedFeaturesType }
     * {@link MinDateTimeType }
     * {@link MaxInstancesType }
     * {@link PrincipalHomeType }
     * {@link TimezoneServerType }
     * {@link MaxAttendeesPerInstanceType }
     * {@link ChildCollectionType }
     * {@link CreationDateTimeType }
     * {@link DisplayNameType }
     * 
     * 
     */
    public List<GetPropertiesBasePropertyType> getChildCollectionOrCreationDateTimeOrDisplayName() {
        if (childCollectionOrCreationDateTimeOrDisplayName == null) {
            childCollectionOrCreationDateTimeOrDisplayName = new ArrayList<GetPropertiesBasePropertyType>();
        }
        return this.childCollectionOrCreationDateTimeOrDisplayName;
    }

}

==> bw-xml-synchws-4.0.8-sources.jar: org/oasis_open/docs/ws_calendar/ns/soap/GetPropertiesResponseType.java <==

package org.oasis_open.docs.ws_calendar.ns.soap;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *          Respond to the getProperties request. The response contains the href 
 *          of the targeted resource and a set of properties for that resource.
 *       
 * 
 * <p>Java class for GetPropertiesResponseType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GetPropertiesResponseType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://docs.oasis-open.org/ws-calendar/ns/soap}BaseResponseType">
 *       &lt;sequence>
 *         &lt;element name="href" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;choice maxOccurs="unbounded" minOccurs="0">
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}childCollection"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}creationDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}displayName"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}lastModifiedDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxAttendeesPerInstance"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxInstances"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}maxResourceSize"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}minDateTime"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}principalHome"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceDescription"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceOwner"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceType"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}resourceTimezoneId"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}supportedCalendarComponentSet"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}supportedFeatures"/>
 *           &lt;element ref="{http://docs.oasis-open.org/ws-calendar/ns/soap}timezoneServer"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GetPropertiesResponseType", propOrder = {
    "href",
    "childCollectionOrCreationDateTimeOrDisplayName"
})
public class GetPropertiesResponseType
    extends BaseResponseType
{

    @XmlElement(required = true)
    protected String href;
    @XmlElements({
        @XmlElement(name = "lastModifiedDateTime", type = LastModifiedDateTimeType.class),
        @XmlElement(name = "displayName", type = DisplayNameType.class),
        @XmlElement(name = "maxAttendeesPerInstance", type = MaxAttendeesPerInstanceType.class),
        @XmlElement(name = "resourceDescription", type = ResourceDescriptionType.class),
        @XmlElement(name = "timezoneServer", type = TimezoneServerType.class),
        @XmlElement(name = "resourceType", type = ResourceTypeType.class),
        @XmlElement(name = "childCollection", type = ChildCollectionType.class),
        @XmlElement(name = "minDateTime", type = MinDateTimeType.class),
        @XmlElement(name = "supportedFeatures", type = SupportedFeaturesType.class),
        @XmlElement(name = "resourceTimezoneId", type = ResourceTimezoneIdType.class),
        @XmlElement(name = "resourceOwner", type = ResourceOwnerType.class),
        @XmlElement(name = "supportedCalendarComponentSet", type = SupportedCalendarComponentSetType.class),
        @XmlElement(name = "principalHome", type = PrincipalHomeType.class),
        @XmlElement(name = "maxDateTime", type = MaxDateTimeType.class),
        @XmlElement(name = "maxInstances", type = MaxInstancesType.class),
        @XmlElement(name = "creationDateTime", type = CreationDateTimeType.class),
        @XmlElement(name = "maxResourceSize", type = MaxResourceSizeType.class)
    })
    protected List<GetPropertiesBasePropertyType> childCollectionOrCreationDateTimeOrDisplayName;

    /**
     * Gets the value of the href property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHref() {
        return href;
    }

    /**
     * Sets the value of the href property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHref(String value) {
        this.href = value;
    }

    /**
     * Gets the value of the childCollectionOrCreationDateTimeOrDisplayName property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the childCollectionOrCreationDateTimeOrDisplayName property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getChildCollectionOrCreationDateTimeOrDisplayName().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LastModifiedDateTimeType }
     * {@link DisplayNameType }
     * {@link MaxAttendeesPerInstanceType }
     * {@link ResourceDescriptionType }
     * {@link TimezoneServerType }
     * {@link ResourceTypeType }
     * {@link ChildCollectionType }
     * {@link MinDateTimeType }
     * {@link SupportedFeaturesType }
     * {@link ResourceTimezoneIdType }
     * {@link ResourceOwnerType }
     * {@link SupportedCalendarComponentSetType }
     * {@link PrincipalHomeType }
     * {@link MaxDateTimeType }
     * {@link MaxInstancesType }
     * {@link CreationDateTimeType }
     * {@link MaxResourceSizeType }
     * 
     * 
     */
    public List<GetPropertiesBasePropertyType> getChildCollectionOrCreationDateTimeOrDisplayName() {
        if (childCollectionOrCreationDateTimeOrDisplayName == null) {
            childCollectionOrCreationDateTimeOrDisplayName = new ArrayList<GetPropertiesBasePropertyType>();
        }
        return this.childCollectionOrCreationDateTimeOrDisplayName;
    }

}
